@@ -270,7 +270,19 @@ class Model(docutils.nodes.GenericNodeVisitor):
     def visit_Setter(self, node):
         ref, attr = node["arguments"][0].split(".")
         entity = self.get_entity(ref)
+
         s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
+        try:
+            # Attempt objectwise assignment if RHS is an entity
+            bits = s.partition(".")
+            donor = self.get_entity(bits[0])
+            val = operator.attrgetter(bits[2])(donor.persona) if bits[2] else donor.persona
+            self.shots[-1].items.append(Model.Property(self.speaker, donor.persona, attr, val))
+        except AttributeError:
+            pass
+        else:
+            return
+
         try:
             val = int(s) if s.isdigit() else node.string_import(s)
         except ValueError:
